@@ -1,6 +1,6 @@
-/*!  \file 
+/*
 
-$Header: /cvsroot/tsp/tsp/src/core/include/tsp_abs_types.h,v 1.20 2005/04/08 14:48:49 le_tche Exp $
+$Header: /cvsroot/tsp/tsp/src/core/include/tsp_abs_types.h,v 1.22 2006/03/04 11:20:21 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -116,6 +116,23 @@ Purpose   : Type abstraction : Stolen from GLIB public headers
 #endif /* Linux / Intel */
 
 
+
+/* Linux / Powerpc */ 							
+#if defined (__linux__) &&  defined (__powerpc__)  
+# include <stdint.h>							
+# define TSP_BYTE_ORDER TSP_BIG_ENDIAN			
+# define TSP_INT64_CONSTANT(val)  (val##LL) 	
+# define TSP_GUINT64_FORMAT "llu"				
+# define TSP_SYSTEM_HAVE_NANOSLEEP 1			
+# define TSP_HAVE_INT64 1						
+#endif /* Linux / Powerpc */						
+												
+												
+
+												
+
+
+
 /* OSF1 / Alpha */
 #if defined (__osf__) && defined (__alpha)
 # include <inttypes.h>
