@@ -1,6 +1,6 @@
 /*
 
-$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_tools.c,v 1.21 2006/02/11 15:40:40 erk Exp $
+$Header: /cvsroot/tsp/tsp/src/util/libbb/bb_tools.c,v 1.24 2006/03/10 22:42:21 erk Exp $
 
 -----------------------------------------------------------------------
 
@@ -43,8 +43,7 @@ Purpose   : BlackBoard Idiom implementation
 #include <libgen.h>
 #include <stdarg.h>
 
-#include <tsp_abs_types.h>
-#include <tsp_const_def.h>
+#include <tsp_prjcfg.h>
 #include <bb_core.h>
 #include <bb_alias.h>
 #include <bb_utils.h>
@@ -152,7 +151,7 @@ S_BB_T*
 bbtools_checkbbname(const char* bbname) {
   S_BB_T* retval;
   retval = NULL;
-  if (bb_attach(&retval,bbname) != E_OK) {
+  if (bb_attach(&retval,bbname) != BB_OK) {
     retval = NULL;
   }  
   return retval;
@@ -295,7 +294,7 @@ bbtools_usage(bbtools_request_t* req) {
   case E_BBTOOLS_GENERIC:
   case E_BBTOOLS_HELP:
     fprintf(req->stream, 
-	    "TSP bb_tools v%s (%s)\n",TSP_SOURCE_VERSION,TSP_PROJECT_URL);
+	    "TSP bb_tools (BB vId=0x%08X, TSP v%s, %s)\n",BB_VERSION_ID,TSP_SOURCE_VERSION,TSP_PROJECT_URL);
     fprintf(req->stream, 
 	    "Usage: %s [bb_tools_opts] <bb_tools_cmd> [cmd_opts]\n",
 	    bbtools_cmdname_tab[E_BBTOOLS_GENERIC]);
@@ -345,8 +344,13 @@ bbtools_usage(bbtools_request_t* req) {
 	    bbtools_cmdname_tab[E_BBTOOLS_CREATE]);  
     break;
   case E_BBTOOLS_PUBLISH:
-    fprintf(req->stream,"Usage : %s <bbname> <symbol_name> [<symbol_type>=BB_UINT] [<arraysize>=1]\n",
+    fprintf(req->stream,"Usage : %s <bbname> <symbol_name> [<symbol_type>=UINT32] [<arraysize>=1]\n",
 	    bbtools_cmdname_tab[E_BBTOOLS_PUBLISH]);  
+    fprintf(req->stream,"bb_tools publishable types (case insensitive) are :\n");	  
+    fprintf(req->stream,"    INT8,INT16,INT32,INT64\n");
+    fprintf(req->stream,"    UINT8,UINT16,UINT32,UINT64\n");
+    fprintf(req->stream,"    FLOAT,DOUBLE\n");
+    fprintf(req->stream,"    CHAR,UCHAR\n");        
     break;
   case E_BBTOOLS_SYNCHRO_SEND:
     fprintf(req->stream,"Usage : %s <bbname>\n",
@@ -459,7 +463,7 @@ bbtools_read(bbtools_request_t* req) {
 		     sym_data_desc.name,
 		     req->bbname);
     } else {
-	 /** the test to determine exeeding array dimension */
+	 /* the test to determine exeeding array dimension */
      if (array_index_len>0) {
 			aliasstack[0]=sym_data_desc;
 			bb_find_aliastack(req->theBB, aliasstack, &aliasstack_size);
@@ -599,10 +603,11 @@ bbtools_write(bbtools_request_t* req) {
 		   				    bbtools_cmdname_tab[E_BBTOOLS_WRITE]);
 		}
 		else if ( (array_index_len>0) && (aliasstack[j-1].dimension <= array_index[array_index_len-1]) ) {
-			bbtools_logMsg(req->stream,"%s: index <%d> exceeding symbol array dimension <%d>\n",
-		   				   bbtools_cmdname_tab[E_BBTOOLS_WRITE],
-		       				array_index[array_index_len-1],
-		                	aliasstack[j-1].dimension);
+			bbtools_logMsg(req->stream,"%s: index <%d> exceeds symbol array dimension <%d> whose valid index range is <0..%d>\n",
+				       bbtools_cmdname_tab[E_BBTOOLS_WRITE],
+				       array_index[array_index_len-1],
+				       aliasstack[j-1].dimension,
+				       aliasstack[j-1].dimension-1);
 		} else {
 		  	if (array_index_len>0) {
 		    	 idx = array_index[array_index_len-1];
@@ -610,7 +615,7 @@ bbtools_write(bbtools_request_t* req) {
 		    	idx = 0;
 		  	}
 	     	if (req->verbose) {
-		   	 bbtools_logMsg(req->stream,"Writing <%s> (index=%d)\n",
+		   	 bbtools_logMsg(req->stream,"Writing <%s> (at index=%d)\n",
 				 req->argv[2],idx);	 		 
 	    	}
 	    	bb_value_write(req->theBB,sym_data_desc,req->argv[2],array_index,array_index_len);
@@ -792,7 +797,7 @@ bbtools_create(bbtools_request_t* req) {
   }
  
   retcode = bb_create(&(req->theBB),req->bbname,ndata,datasize);
-  if ((retcode != E_OK) && (req->verbose)) {
+  if ((retcode != BB_OK) && (req->verbose)) {
     bbtools_logMsg(req->stream,
 		   "%s: creating failed to create BB <%s>\n",
 		   bbtools_cmdname_tab[E_BBTOOLS_CREATE],
@@ -825,11 +830,12 @@ bbtools_publish(bbtools_request_t* req) {
     symbol_type_str = "UINT32";
   }
 
-  /* guess if we have an array type or not using parse array... */
-  bb_utils_parsearrayname(symbol_type_str,
-			  symbol_desc.name,
-			  VARNAME_MAX_SIZE,
-			  dimension,&dimension_len);
+  if (req->argc > 3) {
+    dimension[0] = atoi(req->argv[3]);
+  } else {
+    dimension[0] = 1;
+  }
+
   if (dimension[0]==-1) {
     /* default dimension is 1 (scalar) */
     symbol_desc.dimension = 1;
@@ -856,7 +862,7 @@ bbtools_publish(bbtools_request_t* req) {
       symbol_desc.type_size = sizeof_bb_type(symbol_desc.type);
     } else {
       /* FIXME the user case is not supported */
-      /** @todo */
+      /* @todo */
       printf("\ntaille d'un alias?\n");
       symbol_desc.type_size = 1;
     }
